/* libiso8601/src/libiso8601/400_manip.c
 *
 *  (c)2006, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv2. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/



int iso8601_lt(const struct iso8601_date* d1, const struct iso8601_date* d2)
{
    if(d1->day < d2->day) return 1;
    if(d1->day > d2->day) return 0;
    if(d1->sec < d2->sec) return 1;
    if(d1->sec > d2->sec) return 0;
    if(d1->nsec < d2->nsec) return 1;
    return 0;
}



int iso8601_lte(const struct iso8601_date* d1, const struct iso8601_date* d2)
{
    if(d1->day < d2->day) return 1;
    if(d1->day > d2->day) return 0;
    if(d1->sec < d2->sec) return 1;
    if(d1->sec > d2->sec) return 0;
    if(d1->nsec < d2->nsec) return 1;
    return d1->nsec == d2->nsec;
}



int iso8601_eq(const struct iso8601_date* d1, const struct iso8601_date* d2)
{
    return (d1->day == d2->day) && (d1->sec == d2->sec) && (d1->nsec == d2->nsec);
}



void iso8601_add_elapsed(struct iso8601_date* date, const struct iso8601_elapsed* per)
{
    div_t qr;
    int leapcorrect;

    /* work out number to advance `day' by */
    qr = div(per->sec, 86400);
    leapcorrect = _leap_elapsed_day(date->day, date->day + qr.quot);
    date->day += qr.quot;
    date->sec += qr.rem - leapcorrect;

    date->nsec += per->nsec;
    if(date->nsec > BILLION) {
        ++date->sec;
        date->nsec -= BILLION;
    }

    if(date->sec < 0) {
        --date->day;
        date->sec += iso8601_seconds_leap(date);
    }

    if(date->sec >= iso8601_seconds_leap(date)) {
        date->sec -= iso8601_seconds_leap(date);
        ++date->day;
    }
}



void iso8601_subtract_elapsed(struct iso8601_date* date, const struct iso8601_elapsed* per)
{
    div_t qr;
    int leapcorrect;

    /* work out number to advance `day' by */
    qr = div(per->sec, 86400);
    leapcorrect = _leap_elapsed_day(date->day - qr.quot, date->day);
    date->day -= qr.quot;
    date->sec -= qr.rem - leapcorrect;
    date->nsec -= per->nsec;

    if(date->nsec < 0) {
        --date->sec;
        date->nsec += BILLION;
    }

    if(date->sec < 0) {
        --date->day;
        date->sec += iso8601_seconds_leap(date);
    }

    if(date->sec >= iso8601_seconds_leap(date)) {
        date->sec -= iso8601_seconds_leap(date);
        ++date->day;
    }
}



/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
