/* libiso8601/src/libiso8601/400_manip.h
 *
 *  (c)2006, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv2. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/



/*! \defgroup manip Manipulation routines.

This set of functions is useful for converting dates and times into formats understood by humans,
and vice versa.

*/
/*!@{*/



/*! \brief Comparison (less than).

\param d1 First date to compare.
\param d2 Second date to compare.
\retval non-0 if \a d1 &lt; \a d2
\retval 0 otherwise

*/
int iso8601_lt(const struct iso8601_date* d1, const struct iso8601_date* d2);



/*! \brief Comparison (less than or equal to).

\param d1 First date to compare.
\param d2 Second date to compare.
\retval non-0 if \a d1 &lt;= \a d2
\retval 0 otherwise

*/
int iso8601_lte(const struct iso8601_date* d1, const struct iso8601_date* d2);



/*! \brief Comparison (equality).

\param d1 First date to compare.
\param d2 Second date to compare.
\retval non-0 if \a d1 == \a d2
\retval 0 otherwise

*/
int iso8601_eq(const struct iso8601_date* d1, const struct iso8601_date* d2);



/*! \brief Add a period to a date.

\param[in,out] date Date to modify.
\param per Period to advance date/time by.

*/
void iso8601_add_elapsed(struct iso8601_date* date, const struct iso8601_elapsed* per);



/*! \brief Subtract a period from a date.

\param[in,out] date Date to modify.
\param per Period to regress date/time by.

*/
void iso8601_subtract_elapsed(struct iso8601_date* date, const struct iso8601_elapsed* per);



/*!@}*/
/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
